
import 'package:dio/dio.dart';
import 'package:first_project/data/dtos/anime_dto.dart';
import 'package:first_project/data/mappers/anime_mapper.dart';
import 'package:first_project/data/repositories/api_interface.dart';
import 'package:first_project/presentation/home_page/home_page.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

class AnimeRepository extends ApiInterface {
  static final Dio _dio = Dio()
      ..interceptors.add(PrettyDioLogger(
        requestHeader: true,
        requestBody: true,
      ));

  static const String _baseUrl = 'https://api.jikan.moe';

  @override
  Future<List<CardData>?> loadData({String? q}) async{
    try
        {
          const String url = '$_baseUrl/v4/anime';
          Map<String, dynamic> query = {'limit' : 5, 'q' : q};
          final Response<dynamic> response =
          await _dio.get<Map<dynamic, dynamic>>(
            url,
            queryParameters: query,
          );
          final AnimesDto dto = AnimesDto.fromJson(response.data as Map<String, dynamic>);
          final List<CardData>? data = dto.data?.map((e) => e.toDomain()).toList();
          return data;
        } on DioException catch (e)
    {
      return null;
    }
  }
}