import 'package:first_project/data/repositories/anime_repository.dart';
import 'package:first_project/data/repositories/mock_repository.dart';
import 'package:first_project/domain/models/card.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

part 'card.dart';

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  void initState() {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          'Hello',
          style: Theme.of(context).textTheme.bodyMedium,
        ),
        backgroundColor: Colors.purple,
        duration: const Duration(seconds: 1),
      ));
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.purple,
        title: Text(widget.title),
      ),
      body: const Body(),
    );
  }
}
class Body extends StatefulWidget {
  const Body({super.key});

  @override
  State<Body> createState() => _BodyState();
}

class _BodyState extends State<Body> {
  final AnimeRepository repos = AnimeRepository();
  final searchController = TextEditingController();
  late Future<List<CardData>?> data;

  @override
  void initState() {
    data = repos.loadData();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Center(
        child: FutureBuilder<List<CardData>?>(
          future: data,
          builder: (context, snapshot) => SingleChildScrollView(
            child: snapshot.hasData
                ? Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Padding(
                  padding: const EdgeInsets.all(8),
                  child: CupertinoSearchTextField(
                    controller: searchController,
                    onChanged: (search) {
                      setState(() {
                        data = repos.loadData(q : search);
                      });
                    },
                  ),
                ),
                ...snapshot.data!.map(
                      (e) {
                    return _Card.fromData(
                      e,
                      onLike: (String title, bool isLiked) =>
                          _showLiked(context, title, isLiked),
                      onTap: () => _navToDetails(context, e),
                    );
                  },
                ).toList()
              ],
            )
                : const CircularProgressIndicator(),
          ),
        ));
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }

  void _showLiked(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          'Аниме $title ${isLiked ? 'лайкнуто!' : 'дизлайнуто'}',
          style: Theme.of(context).textTheme.bodyMedium,
        ),
        backgroundColor: Colors.purple,
        duration: const Duration(seconds: 1),
      ));
    });
  }
}
